@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -21,6 +21,7 @@ using namespace MailCommon;
 
 FilterActionMissingAccountDialog::FilterActionMissingAccountDialog(const QStringList &lstAccount, const QString &filtername, QWidget *parent)
     : QDialog(parent)
+    , mAccountList(new MailCommon::KMFilterAccountList(this))
 {
     setModal(true);
     setWindowTitle(i18nc("@title:window", "Select Account"));
@@ -34,7 +35,6 @@ FilterActionMissingAccountDialog::FilterActionMissingAccountDialog(const QString
              filtername));
     label->setWordWrap(true);
     mainLayout->addWidget(label);
-    mAccountList = new MailCommon::KMFilterAccountList(this);
     mAccountList->setObjectName(QStringLiteral("accountlist"));
     mAccountList->applyOnAccount(lstAccount);
     mainLayout->addWidget(mAccountList);
@@ -57,7 +57,7 @@ FilterActionMissingAccountDialog::~FilterActionMissingAccountDialog()
 
 void FilterActionMissingAccountDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "FilterActionMissingAccountDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingAccountDialog");
 
     const QSize size = group.readEntry("Size", QSize(500, 300));
     if (size.isValid()) {
@@ -67,7 +67,7 @@ void FilterActionMissingAccountDialog::readConfig()
 
 void FilterActionMissingAccountDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "FilterActionMissingAccountDialog");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingAccountDialog");
     group.writeEntry("Size", size());
 }
 
