@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -59,7 +59,7 @@ FilterActionMissingIdentityDialog::~FilterActionMissingIdentityDialog()
 
 void FilterActionMissingIdentityDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "FilterActionMissingMissingIdentity");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingMissingIdentity");
 
     const QSize size = group.readEntry("Size", QSize(500, 300));
     if (size.isValid()) {
@@ -69,7 +69,7 @@ void FilterActionMissingIdentityDialog::readConfig()
 
 void FilterActionMissingIdentityDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "FilterActionMissingMissingIdentity");
+    KConfigGroup group(KSharedConfig::openStateConfig(), "FilterActionMissingMissingIdentity");
     group.writeEntry("Size", size());
 }
 
