@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -17,9 +17,7 @@ FilterConvertToSieve::FilterConvertToSieve(const QVector<MailFilter *> &filters)
 {
 }
 
-FilterConvertToSieve::~FilterConvertToSieve()
-{
-}
+FilterConvertToSieve::~FilterConvertToSieve() = default;
 
 void FilterConvertToSieve::convert()
 {
@@ -27,12 +25,12 @@ void FilterConvertToSieve::convert()
     if (!mListFilters.isEmpty()) {
         QStringList requiresModule;
         QString code;
-        for (MailFilter *filter : qAsConst(mListFilters)) {
+        for (MailFilter *filter : std::as_const(mListFilters)) {
             filter->generateSieveScript(requiresModule, code);
             code += QLatin1Char('\n');
         }
         QString requireStr;
-        for (const QString &require : qAsConst(requiresModule)) {
+        for (const QString &require : std::as_const(requiresModule)) {
             requireStr += QStringLiteral("require \"%1\";").arg(require);
             requireStr += QLatin1Char('\n');
         }
