@@ -26,6 +26,7 @@
 #include <KListWidgetSearchLine>
 #include <KMessageBox>
 #include <QFileDialog>
+#include <QPointer>
 #include <QPushButton>
 #include <QRegularExpression>
 
@@ -172,7 +173,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(bool &canceled, Filt
             fileName = QFileDialog::getOpenFileName(d->mParent, title, defaultPath);
             if (fileName.isEmpty()) {
                 canceled = true;
-                return QVector<MailFilter *>(); // cancel
+                return {}; // cancel
             }
         }
         file.setFileName(fileName);
@@ -180,7 +181,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(bool &canceled, Filt
             KMessageBox::error(d->mParent,
                                i18n("The selected file is not readable. "
                                     "Your file access permissions might be insufficient."));
-            return QVector<MailFilter *>();
+            return {};
         }
     }
 
@@ -227,7 +228,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(bool &canceled, Filt
             } else {
                 canceled = true;
                 delete selectThunderBirdFileDialog;
-                return QVector<MailFilter *>();
+                return {};
             }
             delete selectThunderBirdFileDialog;
         } else {
@@ -236,7 +237,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(bool &canceled, Filt
                 KMessageBox::error(d->mParent,
                                    i18n("The selected file is not readable. "
                                         "Your file access permissions might be insufficient."));
-                return QVector<MailFilter *>();
+                return {};
             }
 
             auto thunderBirdFilter = new MailCommon::FilterImporterThunderbird(&file);
@@ -306,7 +307,7 @@ QVector<MailFilter *> FilterImporterExporter::importFilters(bool &canceled, Filt
     }
     delete dlg;
     canceled = true;
-    return QVector<MailFilter *>();
+    return {};
 }
 
 void FilterImporterExporter::exportFilters(const QVector<MailFilter *> &filters, const QUrl &fileName, bool saveAll)
