@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef KMFILTERLISTBOX_H
-#define KMFILTERLISTBOX_H
+#pragma once
 
 #include "search/searchpattern.h"
 #include <QGroupBox>
@@ -50,7 +49,7 @@ public:
     ~QListWidgetFilterItem() override;
 
     void setFilter(MailCommon::MailFilter *filter);
-    MailCommon::MailFilter *filter();
+    Q_REQUIRED_RESULT MailCommon::MailFilter *filter() const;
 
 private:
     MailCommon::MailFilter *mFilter = nullptr;
@@ -245,4 +244,3 @@ private:
     void swapNeighbouringFilters(int untouchedOne, int movedOne);
 };
 }
-#endif // KMFILTERLISTBOX_H
