@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -56,16 +56,14 @@ FilterImporterExporterGui::FilterImporterExporterGui(QWidget *parent)
     act = new QAction(QStringLiteral("GMail filters"), this);
     act->setData(QVariant::fromValue(MailCommon::FilterImporterExporter::GmailFilter));
     menuFilter->addAction(act);
-    connect(menuFilter, QOverload<QAction *>::of(&QMenu::triggered), this, &FilterImporterExporterGui::slotImportFilter);
+    connect(menuFilter, &QMenu::triggered, this, &FilterImporterExporterGui::slotImportFilter);
 
     mTextEdit = new QTextEdit;
     mTextEdit->setReadOnly(true);
     mainLayout->addWidget(mTextEdit);
 }
 
-FilterImporterExporterGui::~FilterImporterExporterGui()
-{
-}
+FilterImporterExporterGui::~FilterImporterExporterGui() = default;
 
 void FilterImporterExporterGui::slotImportFilter(QAction *act)
 {
