@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILCOMMON_FOLDERSETTINGS_H
-#define MAILCOMMON_FOLDERSETTINGS_H
+#pragma once
 
 #include "mailcommon_export.h"
 #include <MessageViewer/Viewer>
@@ -13,8 +12,8 @@
 #include <MessageCore/MailingList>
 using MessageCore::MailingList;
 
-#include <Collection>
-#include <CollectionStatistics>
+#include <Akonadi/Collection>
+#include <Akonadi/CollectionStatistics>
 
 #include <KIO/Job>
 #include <KSharedConfig>
@@ -88,7 +87,7 @@ public:
 
     void setMailingList(const MailingList &mlist);
 
-    MailingList mailingList() const;
+    Q_REQUIRED_RESULT MailingList mailingList() const;
 
     /**
      * Returns true if the replies to mails from this folder should be
@@ -122,10 +121,10 @@ private:
     Akonadi::Collection mCollection;
 
     /** Mailing list attributes */
-    bool mMailingListEnabled;
+    bool mMailingListEnabled = false;
     MailingList mMailingList;
 
-    bool mUseDefaultIdentity;
+    bool mUseDefaultIdentity = true;
     uint mIdentity;
 
     MessageViewer::Viewer::DisplayFormatMessage mFormatMessage = MessageViewer::Viewer::Unknown;
@@ -139,8 +138,6 @@ private:
 
     /** shortcut associated with this folder or null, if none is configured. */
     QKeySequence mShortcut;
-    bool mWriteConfig;
+    bool mWriteConfig = true;
 };
 }
-
-#endif
