@@ -42,13 +42,17 @@ public:
     Q_REQUIRED_RESULT ResponseMDN response() const;
     void setResponse(ResponseMDN newResponse);
 
+    Q_REQUIRED_RESULT KMime::MDN::SendingMode sendingMode() const;
+    void setSendingMode(KMime::MDN::SendingMode newSendingMode);
+
 Q_SIGNALS:
-    void showWarning();
+    void finished();
 
 private:
     Q_REQUIRED_RESULT QPair<bool, KMime::MDN::SendingMode> modifyItem();
     Akonadi::Item mItem;
     ResponseMDN mResponse = Unknown;
+    KMime::MDN::SendingMode mSendingMode = KMime::MDN::SendingMode::SentAutomatically;
     IKernel *const mKernel = nullptr;
 };
 }
