@@ -31,17 +31,17 @@ public:
     /**
      * @copydoc SearchRule::isEmpty()
      */
-    bool isEmpty() const override;
+    Q_REQUIRED_RESULT bool isEmpty() const override;
 
     /**
      * @copydoc SearchRule::matches()
      */
-    bool matches(const Akonadi::Item &item) const override;
+    Q_REQUIRED_RESULT bool matches(const Akonadi::Item &item) const override;
 
     /**
      * @copydoc SearchRule::requiredPart()
      */
-    RequiredPart requiredPart() const override;
+    Q_REQUIRED_RESULT RequiredPart requiredPart() const override;
 
     // Optimized matching not implemented, will use the unoptimized matching
     // from SearchRule
@@ -57,6 +57,6 @@ public:
      * @copydoc SearchRule::addQueryTerms()
      */
     void addQueryTerms(Akonadi::SearchTerm &groupTerm, bool &emptyIsNotAnError) const override;
-    QString informationAboutNotValidRules() const override;
+    Q_REQUIRED_RESULT QString informationAboutNotValidRules() const override;
 };
 }
