@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -21,9 +21,7 @@ using namespace MailCommon;
 class MailCommon::AddTagDialogPrivate
 {
 public:
-    AddTagDialogPrivate()
-    {
-    }
+    AddTagDialogPrivate() = default;
 
     QString mLabel;
     QString mGid;
@@ -48,7 +46,7 @@ AddTagDialog::AddTagDialog(const QList<KActionCollection *> &actions, QWidget *p
 
     auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     d->mOkButton = buttonBox->button(QDialogButtonBox::Ok);
-    d->mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    d->mOkButton->setShortcut(QKeySequence(Qt::CTRL | Qt::Key_Return));
     connect(buttonBox, &QDialogButtonBox::accepted, this, &AddTagDialog::slotSave);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &AddTagDialog::reject);
     d->mOkButton->setDefault(true);
@@ -57,10 +55,7 @@ AddTagDialog::AddTagDialog(const QList<KActionCollection *> &actions, QWidget *p
     mainLayout->addWidget(buttonBox);
 }
 
-AddTagDialog::~AddTagDialog()
-{
-    delete d;
-}
+AddTagDialog::~AddTagDialog() = default;
 
 void AddTagDialog::setTags(const QVector<MailCommon::Tag::Ptr> &tags)
 {
@@ -76,7 +71,7 @@ void AddTagDialog::slotSave()
 {
     const QString name(d->mTagWidget->tagNameLineEdit()->text());
 
-    for (const MailCommon::Tag::Ptr &tag : qAsConst(d->mTags)) {
+    for (const MailCommon::Tag::Ptr &tag : std::as_const(d->mTags)) {
         if (tag->name() == name) {
             KMessageBox::error(this, i18n("Tag %1 already exists", name));
             d->mTagWidget->tagNameLineEdit()->setFocus();
